appdirs: Small Python module for determining appropriate platform-specific dirs, e.g. a "user data dir"
=======================================================================================================

Description
-----------

Small Python module for determining appropriate platform-specific dirs, e.g. a "user data dir"

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/appdirs/

